@@ -1,9 +1,9 @@
 /* File getcol.c
- * August 12, 2013
+ * December 10, 2015
  * By Jessica Mink, Harvard-Smithsonian Center for Astrophysics
  * Send bug reports to jmink@cfa.harvard.edu
 
-   Copyright (C) 1999-2013
+   Copyright (C) 1999-2015
    Smithsonian Astrophysical Observatory, Cambridge, MA USA
 
    This program is free software; you can redistribute it and/or
@@ -37,7 +37,7 @@
 #define MAXFILES	2000
 #define MAXLINES	100000
 
-static char *RevMsg = "GETCOL WCSTools 3.9.2, 15 May 2015, Jessica Mink SAO";
+static char *RevMsg = "GETCOL WCSTools 3.9.3, 08 June 2016, Jessica Mink SAO";
 
 static void usage();
 static int ListFile();
@@ -538,6 +538,10 @@ char	*lfile;		/* Name of file with lines to list */
     double *qmed1 = NULL;
     double qsum = 0.0;
     double qsum1;
+    int ncstr;		/* Argument isnum() value */
+    int ncstr0;		/* Original argument isnum() value */
+    int ncval;		/* Column isnum() value */
+    int ncval0;		/* Column isnum() before any conversion */
     int *nsum;
     int *nent;
     int *hms;		/* Flag for hh:mm:ss or dd:mm:ss format */
@@ -776,35 +780,43 @@ char	*lfile;		/* Name of file with lines to list */
 			pass = 0;
 	
 		    /* Extract test value from comparison string */
+		    tcond = *ccond[icond];
 		    cstr = ccond[icond]+1;
-		    if (strchr (cstr, ':')) {
+		    ncstr0 = isnum (cstr);
+
+		    /* If test value is sexigesimal, convert it to decimal */
+		    if (ncstr0 == 3) {
 			dnum = str2dec (cstr);
 			num2str (numstr, dnum, 0, 7);
 			cstr = numstr;
 			}
-		    else if (isnum (cstr) == 1) {
+
+		    /* If test value is integer, use value for that column */
+		    else if (ncstr0 == 1) {
 			itok = atoi (cstr);
 			getoken (&tokens, itok, token1, MAX_LTOK);
 			cstr = token1;
 			}
 		    strfix (cstr, 0, 1);
+		    ncstr = isnum (cstr);
 	
 		    /* Read comparison value from header */
-		    tcond = *ccond[icond];
-		    *ccond[icond] = (char) 0;
 		    itok = atoi (cond[icond]);
-		    *ccond[icond] = tcond;
 		    getoken (&tokens, itok, token, MAX_LTOK);
 		    cval = token;
-		    if (strchr (cval, ':')) {
+		    ncval0 = isnum (cval);
+
+		    /* If column value is sexigesimal, convert it to decimal */
+		    if (ncval0 == 3) {
 			dnum = str2dec (cval);
 			num2str (numstr1, dnum, 0, 7);
 			cval = numstr1;
 			}
 		    strfix (cval, 0, 1);
+		    ncval = isnum (cval);
 	
 		    /* Compare floating point numbers */
-		    if (isnum (cstr) == 2 && isnum (cval)) {
+		    if (ncstr == 2 && ncval) {
 			dcond = atof (cstr);
 			dval = atof (cval);
 			if (tcond == '=' && dval == dcond)
@@ -818,7 +830,7 @@ char	*lfile;		/* Name of file with lines to list */
 			}
 	
 		    /* Compare integers */
-		    else if (isnum (cstr) == 1 && isnum (cval)) {
+		    else if (ncstr == 1 && ncval) {
 			jcond = (int) atof (cstr);
 			jval = (int) atof (cval);
 			if (tcond == '=' && jval == jcond)
@@ -830,7 +842,14 @@ char	*lfile;		/* Name of file with lines to list */
 			if (tcond == '<' && jval < jcond)
 			    pass = 1;
 			}
-	
+
+		    /* Check number type */
+		    else if (cstr[0] == 'n' && ncval0) {
+			ncstr = atoi (cstr+1);
+			if (ncval0 == ncstr)
+			    pass = 1;
+			}
+
 		    /* Compare strings (only equal or not equal */
 		    else {
 			if (tcond == '=' && !strcmp (cstr, cval))
@@ -838,6 +857,7 @@ char	*lfile;		/* Name of file with lines to list */
 			if (tcond == '#' && strcmp (cstr, cval))
 			    pass = 1;
 			}
+
 		    if (condand && !pass)
 			break;
 		    }
@@ -1021,35 +1041,51 @@ char	*lfile;		/* Name of file with lines to list */
 			pass = 0;
 	
 		    /* Extract test value from comparison string */
+		    tcond = *ccond[icond];
 		    cstr = ccond[icond]+1;
-		    if (strchr (cstr, ':')) {
+		    ncstr0 = isnum (cstr);
+
+		    /* Convert sexigesimal test value to decimal */
+		    if (ncstr0 == 3) {
 			dnum = str2dec (cstr);
 			num2str (numstr, dnum, 0, 7);
 			cstr = numstr;
 			}
-		    else if (isnum (cstr) == 1) {
+
+		    /* Get column value if integer test value */
+		    else if (ncstr0 == 1 && atoi (cstr) != 0) {
 			itok = atoi (cstr);
 			getoken (&tokens, itok, token1, MAX_LTOK);
 			cstr = token1;
+			ncstr = isnum (cstr);
+
+			/* Convert sexigesimal column value to decimal */
+			if (ncstr == 3) {
+			    dnum = str2dec (cstr);
+			    num2str (numstr, dnum, 0, 7);
+			    cstr = numstr;
+			    }
 			}
 		    strfix (cstr, 0, 1);
+		    ncstr = isnum (cstr);
 	
-		    /* Read comparison value from header */
-		    tcond = *ccond[icond];
-		    *ccond[icond] = (char) 0;
+		    /* Read value to check against from line */
 		    itok = atoi (cond[icond]);
-		    *ccond[icond] = tcond;
 		    getoken (&tokens, itok, token, MAX_LTOK);
 		    cval = token;
-		    if (strchr (cval, ':')) {
+		    ncval0 = isnum (cval);
+
+		    /* Convert sexigesimal column value to decimal */
+		    if (ncval0 == 3) {
 			dnum = str2dec (cval);
 			num2str (numstr, dnum, 0, 7);
 			cval = numstr;
 			}
 		    strfix (cval, 0, 1);
+		    ncval = isnum (cval);
 	
 		    /* Compare floating point numbers */
-		    if (isnum (cstr) == 2 && isnum (cval)) {
+		    if (ncstr == 2 && ncval > 0 && ncval < 3) {
 			dcond = atof (cstr);
 			dval = atof (cval);
 			if (tcond == '=' && dval == dcond)
@@ -1063,7 +1099,7 @@ char	*lfile;		/* Name of file with lines to list */
 			}
 	
 		    /* Compare integers */
-		    else if (isnum (cstr) == 1 && isnum (cval)) {
+		    else if (ncstr == 1 && ncval > 0 && ncval < 3) {
 			jcond = atoi (cstr);
 			jval = atoi (cval);
 			if (tcond == '=' && jval == jcond)
@@ -1075,6 +1111,13 @@ char	*lfile;		/* Name of file with lines to list */
 			if (tcond == '<' && jval < jcond)
 			    pass = 1;
 			}
+
+		    /* Check number type */
+		    else if (cstr[0] == 'n' && ncval0) {
+			ncstr = atoi (cstr+1);
+			if (ncval0 == ncstr)
+			    pass = 1;
+			}
 	
 		    /* Compare strings (only equal or not equal */
 		    else {
@@ -1784,4 +1827,8 @@ void *pd1, *pd2;
  * Apr 18 2011	Fix allocation bug for median of too many entries
  * 
  * Aug 12 2013	Subtract one from returned token count for accuracy
+ *
+ * Nov 19 2015	Add test <col>=n[0][1][2][3][4] to check for numericness
+ *
+ * Dec 10 2015	Fix tests
  */
