@@ -37,7 +37,7 @@ static int nlog = 10000;
 static void usage();
 void SaveGSC2();
 
-static char *RevMsg = "GSC2CAT WCSTools 3.9.2, 15 May 2015, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "GSC2CAT WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 main (ac, av)
 int ac;
