@@ -28,7 +28,7 @@
 #include <string.h>
 #include "libwcs/fitsfile.h"
 
-static char *RevMsg = "ISFILE WCSTools 3.9.2, 15 May 2015, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "ISFILE WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 int
 main (ac, av)
