@@ -27,7 +27,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-static char *RevMsg = "ISRANGE WCSTools 3.9.2, 15 May 2015, Jessica Mink (jmink@cfa.harvard.edu)";
+static char *RevMsg = "ISRANGE WCSTools 3.9.3, 08 June 2016, Jessica Mink (jmink@cfa.harvard.edu)";
 
 static int isrange();
 
