@@ -12,7 +12,7 @@
 
 extern int   ned_errno;
 static void PrintUsage();
-static char *RevMsg = "SIMPOS 3.9.2, 15 May 2015, Jessica Mink SAO";
+static char *RevMsg = "SIMPOS 3.9.3, 08 June 2016, Jessica Mink SAO";
 
 int
 main (ac, av)
